.. Spinta documentation master file, created by
   sphinx-quickstart on Wed Jan  8 12:01:54 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Spinta documentation!
=====================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   manual/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
